==> bcutil-lts8on-2.73.4.jar: META-INF/versions/9/module-info.java <==
module org.bouncycastle.lts.util {
    requires org.bouncycastle.lts.prov;

    exports org.bouncycastle.asn1.bsi;
    exports org.bouncycastle.asn1.cmc;
    exports org.bouncycastle.asn1.cmp;
    exports org.bouncycastle.asn1.cms;
    exports org.bouncycastle.asn1.cms.ecc;
    exports org.bouncycastle.asn1.crmf;
    exports org.bouncycastle.asn1.dvcs;
    exports org.bouncycastle.asn1.eac;
    exports org.bouncycastle.asn1.esf;
    exports org.bouncycastle.asn1.ess;
    exports org.bouncycastle.asn1.est;
    exports org.bouncycastle.asn1.icao;
    exports org.bouncycastle.asn1.isismtt;
    exports org.bouncycastle.asn1.isismtt.ocsp;
    exports org.bouncycastle.asn1.isismtt.x509;
    exports org.bouncycastle.asn1.smime;
    exports org.bouncycastle.asn1.tsp;
    exports org.bouncycastle.oer;
    exports org.bouncycastle.oer.its.etsi103097;
    exports org.bouncycastle.oer.its.etsi103097.extension;
    exports org.bouncycastle.oer.its.ieee1609dot2;
    exports org.bouncycastle.oer.its.ieee1609dot2.basetypes;
    exports org.bouncycastle.oer.its.ieee1609dot2dot1;
    exports org.bouncycastle.oer.its.template.etsi102941;
    exports org.bouncycastle.oer.its.template.etsi102941.basetypes;
    exports org.bouncycastle.oer.its.template.etsi103097;
    exports org.bouncycastle.oer.its.template.etsi103097.extension;
    exports org.bouncycastle.oer.its.template.ieee1609dot2;
    exports org.bouncycastle.oer.its.template.ieee1609dot2.basetypes;
    exports org.bouncycastle.oer.its.template.ieee1609dot2dot1;

}

==> bcutil-lts8on-2.73.8.jar: META-INF/versions/9/module-info.java <==
module org.bouncycastle.lts.util {
    requires org.bouncycastle.lts.prov;

    exports org.bouncycastle.asn1.bsi;
    exports org.bouncycastle.asn1.cmc;
    exports org.bouncycastle.asn1.cmp;
    exports org.bouncycastle.asn1.cms;
    exports org.bouncycastle.asn1.cms.ecc;
    exports org.bouncycastle.asn1.crmf;
    exports org.bouncycastle.asn1.dvcs;
    exports org.bouncycastle.asn1.eac;
    exports org.bouncycastle.asn1.edec;
    exports org.bouncycastle.asn1.esf;
    exports org.bouncycastle.asn1.ess;
    exports org.bouncycastle.asn1.est;
    exports org.bouncycastle.asn1.icao;
    exports org.bouncycastle.asn1.isismtt;
    exports org.bouncycastle.asn1.isismtt.ocsp;
    exports org.bouncycastle.asn1.isismtt.x509;
    exports org.bouncycastle.asn1.oiw;
    exports org.bouncycastle.asn1.rosstandart;
    exports org.bouncycastle.asn1.smime;
    exports org.bouncycastle.asn1.tsp;
    exports org.bouncycastle.oer;
    exports org.bouncycastle.oer.its.etsi103097;
    exports org.bouncycastle.oer.its.etsi103097.extension;
    exports org.bouncycastle.oer.its.ieee1609dot2;
    exports org.bouncycastle.oer.its.ieee1609dot2.basetypes;
    exports org.bouncycastle.oer.its.ieee1609dot2dot1;
    exports org.bouncycastle.oer.its.etsi102941;
    exports org.bouncycastle.oer.its.etsi102941.basetypes;
    exports org.bouncycastle.oer.its.template.etsi102941;
    exports org.bouncycastle.oer.its.template.etsi102941.basetypes;
    exports org.bouncycastle.oer.its.template.etsi103097;
    exports org.bouncycastle.oer.its.template.etsi103097.extension;
    exports org.bouncycastle.oer.its.template.ieee1609dot2;
    exports org.bouncycastle.oer.its.template.ieee1609dot2.basetypes;
    exports org.bouncycastle.oer.its.template.ieee1609dot2dot1;

}
